Module component

Module component 

Structs

Component
A component definition - a template that can be instantiated
ComponentRegistry
Registry of all available components
ResolvedComponent
Result from component resolution Contains the source code and the resolved path for the component

Type Aliases

ComponentResolver
Callback type for resolving component source code Takes component name and optional path context, returns resolved component Path context is the file path where this component is being referenced from Resolver should return (source_code, resolved_path) where resolved_path is the absolute path to the component file (used for resolving nested components)