pub struct RouterRoute {
pub path: String,
pub children: Vec<IRNode>,
}Expand description
A router route with a path pattern and children to render when matched.
Fields
path: StringURL path pattern. Currently exact match; :param segments are
reserved for future support.
children: Vec<IRNode>Children to render when the current location matches path.
Implementations