Module diff

Module diff 

Functions

create_ir_node_tree
Create a tree from an IRNode (supports ForEach, When/If, and regular elements)
create_tree
Create a new subtree from an element
diff_props
Diff two sets of props and generate SetProp/RemoveProp patches
reconcile
Reconcile an element tree against the instance tree and generate patches
reconcile_ir
Reconcile an IRNode tree against the instance tree and generate patches This is the primary entry point for the IRNode-based reconciliation system, which supports first-class ForEach, When/If, and custom item variable names.
reconcile_ir_node
Reconcile an existing tree against a new IRNode
reconcile_ir_with_ds
Reconcile an IRNode tree with data source context
reconcile_node
Reconcile a single node with a new element
reconcile_with_ds
Reconcile an element tree with data source context