Module render

Module render 

Shared rendering logic for Engine and WasmEngine

This module contains the common rendering logic to avoid code duplication between the native Engine and WASM WasmEngine implementations.

Functions

render_dirty_nodes
Render only dirty nodes (optimized for state changes) This is shared logic used by both Engine and WasmEngine
render_dirty_nodes_with_deps
Render only dirty nodes with dependency tracking for List reconciliation