Module serialize

Module serialize 

Serialization for the Remote UI protocol.

The Remote UI protocol allows the Hypen engine to run on a server while a thin client renders the UI. See RemoteMessage for the wire format.

Re-exports

pub use remote::InitialTree;
pub use remote::PatchStream;
pub use remote::RemoteMessage;

Modules

remote