ComponentRegistry

Struct ComponentRegistry 

pub struct ComponentRegistry { /* private fields */ }
Registry of all available components

Implementations

Source

impl ComponentRegistry

pub fn new() -> Self

pub fn register_primitive(&mut self, name: &str)

Register a primitive element name to skip component resolution Called by the renderer to mark built-in DOM elements

pub fn set_resolver(&mut self, resolver: ComponentResolver)

Set the component resolver callback

pub fn register(&mut self, component: Component)

pub fn get(&self, name: &str, context_path: Option<&str>) -> Option<&Component>

Get a component by name and optional context path

pub fn expand(&mut self, element: &Element) -> Element

pub fn expand_children( &mut self, element: &Element, context_path: Option<&str>, ) -> Vec<Element>

Force expand an element’s children (used for lazy components) This will expand children that were previously kept unexpanded

pub fn expand_ir_node(&mut self, node: &IRNode) -> IRNode

Expand an IRNode recursively, expanding any Element nodes via the component registry