Module node
hypen_
engine
0.3.3
Module node
Module Items
Structs
Enums
Type Aliases
In hypen_
engine::
ir
hypen_engine
::
ir
Module
node
Structs

Conditional
Branch
A conditional branch with a pattern and children
Element
Core IR element representing a component instance or primitive
NodeId
Props
Arc-wrapped properties for O(1) clone with copy-on-write semantics.
Enums

IRNode
First-class IR node - distinguishes between regular elements and control flow constructs This provides type-safe pattern matching in the reconciler and clear separation of concerns
Value
IR value - either static or a binding to reactive state
Type Aliases

Props
Map
Properties map type (underlying storage)