ModuleInstance

Struct ModuleInstance 

pub struct ModuleInstance {
    pub module: Module,
    pub state: Value,
    pub mounted: bool,
    /* private fields */
}
Module instance that holds the current state

Fields

module: Module

Module metadata

state: Value

Current state snapshot

mounted: bool

Whether the module is currently mounted

Implementations

Source

impl ModuleInstance

pub fn new(module: Module, initial_state: Value) -> Self

pub fn set_on_created<F>(&mut self, callback: F)
where F: Fn() + Send + Sync + 'static,

Set the on_created lifecycle callback

pub fn set_on_destroyed<F>(&mut self, callback: F)
where F: Fn() + Send + Sync + 'static,

Set the on_destroyed lifecycle callback

pub fn mount(&mut self)

Mount the module (call on_created)

pub fn unmount(&mut self)

Unmount the module (call on_destroyed)

pub fn update_state(&mut self, patch: Value)

Update state from a patch

pub fn update_state_sparse(&mut self, paths: &[String], values: &Value)

Update state from sparse path-value pairs This is more efficient than sending the full state when only a few paths changed

pub fn get_state(&self) -> &Value

Get the current state