pub struct InstanceNode {
pub id: NodeId,
pub element_type: String,
pub props: IndexMap<String, Value>,
pub raw_props: IndexMap<String, Value>,
pub element_template: Option<Element>,
pub key: Option<String>,
pub parent: Option<NodeId>,
pub children: Vec<NodeId>,
}Expand description
Instance node - a concrete instance of an element in the tree
Fields
id: NodeIdUnique node ID
element_type: StringElement type (e.g., “Column”, “Text”)
props: IndexMap<String, Value>Resolved props (bindings evaluated to actual values)
raw_props: IndexMap<String, Value>Raw props (including bindings) for change detection
element_template: Option<Element>Original element template (for List re-rendering) Only populated for List elements that need to re-render children
key: Option<String>Optional key for reconciliation
parent: Option<NodeId>Parent node ID
children: Vec<NodeId>Child node IDs (ordered)
Implementations